@@ -10,7 +10,7 @@ from .shared import (
     validate_list_model, validate_list_model_config, validate_list_dates_format,
     validate_list_duplicate_values
 )
-from .input import validate_must_include_id, validate_input_country
+from .input import validate_must_include_id, validate_input_country, validate_related_impacts
 from .practice import (
     validate_cropResidueManagement, validate_longFallowPeriod, validate_excretaManagement, validate_no_tillage,
     validate_tillage_site_type, validate_tillage_values
@@ -198,7 +198,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_properties_default_value(cycle, 'inputs'),
         validate_properties_valueType(cycle, 'inputs'),
         validate_must_include_id(cycle['inputs']),
-        validate_input_country(cycle, 'inputs')
+        validate_input_country(cycle, 'inputs'),
+        validate_related_impacts(cycle, 'inputs', node_map)
     ] if len(cycle.get('inputs', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'products'),
         validate_list_dates_format(cycle, 'products'),
