@@ -1,8 +1,8 @@
-from hestia_earth.schema import SiteSiteType
+from hestia_earth.schema import SiteSiteType, TermTermType
 
 
 def _validate_site_type(data_completeness: dict, site: dict):
-    key = 'manureManagement'
+    key = TermTermType.EXCRETAMANAGEMENT.value
     site_type = site.get('siteType')
     return site_type != SiteSiteType.CROPLAND.value or data_completeness.get(key) is True or {
         'level': 'warning',
