@@ -202,6 +202,8 @@ def validate_require_startDate_endDate(measurements: list):
 
 
 def validate_with_models(site: dict, list_key: str):
+    threshold = 0.25
+
     def validate(values: tuple):
         index, blank_node = values
         term_id = blank_node.get('term', {}).get('@id')
@@ -210,7 +212,7 @@ def validate_with_models(site: dict, list_key: str):
         expected_value = MEASUREMENTS_MODELS[term_id](site, blank_node) if term_id in MEASUREMENTS_MODELS else value
         delta = value_difference(value, expected_value) if expected_value else 0
         data_path = '' if blank_node.get('value') is None else '.value'
-        return delta < 0.25 or {
+        return delta < threshold or {
             'level': 'warning',
             'dataPath': f".{list_key}[{index}]{data_path}",
             'message': 'the measurement provided might be in error',
@@ -218,7 +220,8 @@ def validate_with_models(site: dict, list_key: str):
                 'term': blank_node.get('term', {}),
                 'current': value,
                 'expected': expected_value,
-                'delta': delta * 100
+                'delta': delta * 100,
+                'threshold': threshold
             }
         }
 
