@@ -13,7 +13,9 @@ from .measurement import (
     validate_soilTexture, validate_depths, validate_required_depths, validate_value_min_max, validate_term_unique,
     validate_require_startDate_endDate, validate_with_models, validate_value_length
 )
-from .practice import validate_cropResidueManagement, validate_longFallowPeriod
+from .practice import (
+    validate_cropResidueManagement, validate_longFallowPeriod, validate_no_tillage
+)
 from .property import (
     validate_valueType as validate_properties_valueType, validate_default_value as validate_properties_default_value
 )
@@ -131,6 +133,7 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_list_term_percent(site, 'practices'),
         validate_cropResidueManagement(site.get('practices')),
         validate_longFallowPeriod(site.get('practices')),
+        validate_no_tillage(site.get('practices')),
         validate_properties_default_value(site, 'practices'),
         validate_properties_valueType(site, 'practices')
     ] if 'practices' in site else [])
