@@ -9,14 +9,16 @@ from hestia_earth.validation.validators.cycle import (
     validate_economicValueShare,
     validate_sum_aboveGroundCropResidue,
     validate_crop_residue_completeness,
-    validate_siteDuration, validate_otherSites_length, validate_otherSites_cycleDuration
+    validate_siteDuration,
+    validate_otherSites_length,
+    validate_otherSites_cycleDuration
 )
 
 
 def test_validate_valid():
     with open(f"{fixtures_path}/cycle/valid.json") as f:
         node = json.load(f)
-    assert validate_cycle(node) == [True] * 44
+    assert validate_cycle(node) == [True] * 45
 
 
 def test_validate_cycle_dates_valid():
