@@ -15,7 +15,7 @@ from hestia_earth.validation.validators.practice import (
 
 def test_validate_cropResidueManagement_valid():
     # no practices should be valid
-    assert validate_cropResidueManagement([])
+    assert validate_cropResidueManagement([]) is True
 
     with open(f"{fixtures_path}/practice/cropResidueManagement/valid.json") as f:
         data = json.load(f)
@@ -37,7 +37,7 @@ def test_validate_cropResidueManagement_invalid():
 
 def test_validate_longFallowPeriod_valid():
     # no practices should be valid
-    assert validate_longFallowPeriod([])
+    assert validate_longFallowPeriod([]) is True
 
     with open(f"{fixtures_path}/practice/longFallowPeriod/valid.json") as f:
         data = json.load(f)
@@ -56,7 +56,7 @@ def test_validate_longFallowPeriod_invalid():
 
 def test_validate_excretaManagement_valid():
     # no practices should be valid
-    assert validate_excretaManagement({}, [])
+    assert validate_excretaManagement({}, []) is True
 
     with open(f"{fixtures_path}/practice/excretaManagement/valid.json") as f:
         cycle = json.load(f)
@@ -75,7 +75,7 @@ def test_validate_excretaManagement_invalid():
 
 def test_validate_no_tillage_valid():
     # no practices should be valid
-    assert validate_no_tillage([])
+    assert validate_no_tillage([]) is True
 
     with open(f"{fixtures_path}/practice/noTillage/valid.json") as f:
         data = json.load(f)
@@ -99,7 +99,7 @@ def test_validate_no_tillage_invalid():
 
 def test_validate_tillage_site_type_valid():
     # no practices should be valid
-    assert validate_tillage_site_type([], {})
+    assert validate_tillage_site_type([], {}) is True
 
     with open(f"{fixtures_path}/practice/tillage-siteType/valid.json") as f:
         cycle = json.load(f)
@@ -125,7 +125,7 @@ def test_validate_tillage_site_type_warning():
 
 def test_validate_tillage_values_valid():
     # no practices should be valid
-    assert validate_tillage_values([])
+    assert validate_tillage_values([]) is True
 
     with open(f"{fixtures_path}/practice/tillage-values/valid-no-values.json") as f:
         data = json.load(f)
